@@ -83,13 +83,15 @@ testthat_shell_connection <- function() {
   get(".testthat_spark_connection", envir = .GlobalEnv)
 }
 
-testthat_tbl <- function(name) {
+testthat_tbl <- function(name, data = NULL, repartition = 0L) {
   sc <- testthat_spark_connection()
+
   tbl <- tryCatch(dplyr::tbl(sc, name), error = identity)
   if (inherits(tbl, "error")) {
-    data <- eval(as.name(name), envir = parent.frame())
-    tbl <- dplyr::copy_to(sc, data, name = name)
+    if (is.null(data)) data <- eval(as.name(name), envir = parent.frame())
+    tbl <- dplyr::copy_to(sc, data, name = name, repartition = repartition)
   }
+
   tbl
 }
 
