@@ -2,7 +2,8 @@ context("kubernetes config")
 
 test_that("spark_kubernetes_config can generate correct config", {
   expect_equal(
-    spark_config_kubernetes("k8s://https://192.168.99.100:8443", driver = "spark-driver", forward = FALSE),
+    spark_config_kubernetes("k8s://https://192.168.99.100:8443", driver = "spark-driver",
+                            forward = FALSE, fix_config = FALSE),
     list(
       spark.master = "k8s://https://192.168.99.100:8443",
       sparklyr.shell.master = "k8s://https://192.168.99.100:8443",
@@ -10,6 +11,8 @@ test_that("spark_kubernetes_config can generate correct config", {
       sparklyr.gateway.remote = TRUE,
       sparklyr.shell.name = "sparklyr",
       sparklyr.shell.class = "sparklyr.Shell",
+      sparklyr.connect.timeout = 120,
+      sparklyr.web.spark = "http://localhost:4040",
       sparklyr.shell.conf = c(
         "spark.kubernetes.container.image=spark:sparklyr",
         "spark.kubernetes.driver.pod.name=spark-driver",
