@@ -42,7 +42,9 @@ test_that("ft_minhash_lsh() works properly", {
     ft_vector_assembler(paste0("V", 0:5), "features")
   lsh <- ft_minhash_lsh(
     sc, input_col = "features", output_col = "hashes",
-    num_hash_tables = 5, dataset = dfA_tbl, seed = 666)
+    num_hash_tables = 5, seed = 666
+  ) %>%
+    ml_fit(dfA_tbl)
   transformed <- lsh %>%
     ml_transform(dfA_tbl) %>%
     collect()
@@ -54,11 +56,14 @@ test_that("ft_minhash_lsh() works properly", {
     nrow(transformed),
     3
   )
+
+  # Spark 2.4 does not return repeated rows if the neighbour is the same
   expect_equal(
     ml_approx_nearest_neighbors(lsh, dfA_tbl, c(0, 1, 0, 1, 0, 0), num_nearest_neighbors = 2) %>%
-      pull(distCol),
-    c(0.75, 0.75)
+      pull(distCol)  %>% head(1),
+    0.75
   )
+
   expect_equal(
     ml_approx_similarity_join(lsh, dfA_tbl, dfB_tbl, 0.6) %>%
       arrange(id_a, id_b) %>%
